@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,33 +16,47 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.binaryauthorization_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
+from google.protobuf import timestamp_pb2  # type: ignore
+
 from google.cloud.binaryauthorization_v1.services.binauthz_management_service_v1 import (
     pagers,
 )
-from google.cloud.binaryauthorization_v1.types import resources
-from google.cloud.binaryauthorization_v1.types import service
-from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import BinauthzManagementServiceV1Transport, DEFAULT_CLIENT_INFO
+from google.cloud.binaryauthorization_v1.types import resources, service
+
+from .transports.base import DEFAULT_CLIENT_INFO, BinauthzManagementServiceV1Transport
 from .transports.grpc import BinauthzManagementServiceV1GrpcTransport
 from .transports.grpc_asyncio import BinauthzManagementServiceV1GrpcAsyncIOTransport
+from .transports.rest import BinauthzManagementServiceV1RestTransport
 
 
 class BinauthzManagementServiceV1ClientMeta(type):
@@ -60,9 +74,11 @@ class BinauthzManagementServiceV1ClientMeta(type):
     _transport_registry[
         "grpc_asyncio"
     ] = BinauthzManagementServiceV1GrpcAsyncIOTransport
+    _transport_registry["rest"] = BinauthzManagementServiceV1RestTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: Optional[str] = None,
     ) -> Type[BinauthzManagementServiceV1Transport]:
         """Returns an appropriate transport class.
 
@@ -177,10 +193,14 @@ class BinauthzManagementServiceV1Client(
         return self._transport
 
     @staticmethod
-    def attestor_path(project: str, attestor: str,) -> str:
+    def attestor_path(
+        project: str,
+        attestor: str,
+    ) -> str:
         """Returns a fully-qualified attestor string."""
         return "projects/{project}/attestors/{attestor}".format(
-            project=project, attestor=attestor,
+            project=project,
+            attestor=attestor,
         )
 
     @staticmethod
@@ -190,9 +210,13 @@ class BinauthzManagementServiceV1Client(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def policy_path(project: str,) -> str:
+    def policy_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified policy string."""
-        return "projects/{project}/policy".format(project=project,)
+        return "projects/{project}/policy".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_policy_path(path: str) -> Dict[str, str]:
@@ -201,7 +225,9 @@ class BinauthzManagementServiceV1Client(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -214,9 +240,13 @@ class BinauthzManagementServiceV1Client(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -225,9 +255,13 @@ class BinauthzManagementServiceV1Client(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -236,9 +270,13 @@ class BinauthzManagementServiceV1Client(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -247,10 +285,14 @@ class BinauthzManagementServiceV1Client(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -275,7 +317,7 @@ class BinauthzManagementServiceV1Client(
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -330,8 +372,8 @@ class BinauthzManagementServiceV1Client(
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, BinauthzManagementServiceV1Transport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, BinauthzManagementServiceV1Transport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the binauthz management service v1 client.
@@ -345,7 +387,7 @@ class BinauthzManagementServiceV1Client(
             transport (Union[str, BinauthzManagementServiceV1Transport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -375,6 +417,7 @@ class BinauthzManagementServiceV1Client(
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -422,15 +465,16 @@ class BinauthzManagementServiceV1Client(
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def get_policy(
         self,
-        request: Union[service.GetPolicyRequest, dict] = None,
+        request: Optional[Union[service.GetPolicyRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Policy:
         r"""A [policy][google.cloud.binaryauthorization.v1.Policy] specifies
@@ -445,10 +489,15 @@ class BinauthzManagementServiceV1Client(
         [policy][google.cloud.binaryauthorization.v1.Policy] if the
         project does not have one.
 
+        .. code-block:: python
 
-
-        .. code-block::
-
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1
 
             def sample_get_policy():
@@ -522,18 +571,23 @@ class BinauthzManagementServiceV1Client(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     def update_policy(
         self,
-        request: Union[service.UpdatePolicyRequest, dict] = None,
+        request: Optional[Union[service.UpdatePolicyRequest, dict]] = None,
         *,
-        policy: resources.Policy = None,
+        policy: Optional[resources.Policy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Policy:
         r"""Creates or updates a project's
@@ -545,10 +599,15 @@ class BinauthzManagementServiceV1Client(
         NOT_FOUND if the project does not exist, INVALID_ARGUMENT if the
         request is malformed.
 
+        .. code-block:: python
 
-
-        .. code-block::
-
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1
 
             def sample_update_policy():
@@ -631,20 +690,25 @@ class BinauthzManagementServiceV1Client(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     def create_attestor(
         self,
-        request: Union[service.CreateAttestorRequest, dict] = None,
+        request: Optional[Union[service.CreateAttestorRequest, dict]] = None,
         *,
-        parent: str = None,
-        attestor_id: str = None,
-        attestor: resources.Attestor = None,
+        parent: Optional[str] = None,
+        attestor_id: Optional[str] = None,
+        attestor: Optional[resources.Attestor] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
         r"""Creates an
@@ -656,10 +720,15 @@ class BinauthzManagementServiceV1Client(
         the [attestor][google.cloud.binaryauthorization.v1.Attestor]
         already exists.
 
+        .. code-block:: python
 
-
-        .. code-block::
-
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1
 
             def sample_create_attestor():
@@ -762,18 +831,23 @@ class BinauthzManagementServiceV1Client(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     def get_attestor(
         self,
-        request: Union[service.GetAttestorRequest, dict] = None,
+        request: Optional[Union[service.GetAttestorRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
         r"""Gets an
@@ -782,10 +856,15 @@ class BinauthzManagementServiceV1Client(
         [attestor][google.cloud.binaryauthorization.v1.Attestor] does
         not exist.
 
+        .. code-block:: python
 
-
-        .. code-block::
-
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1
 
             def sample_get_attestor():
@@ -860,18 +939,23 @@ class BinauthzManagementServiceV1Client(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     def update_attestor(
         self,
-        request: Union[service.UpdateAttestorRequest, dict] = None,
+        request: Optional[Union[service.UpdateAttestorRequest, dict]] = None,
         *,
-        attestor: resources.Attestor = None,
+        attestor: Optional[resources.Attestor] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
         r"""Updates an
@@ -880,10 +964,15 @@ class BinauthzManagementServiceV1Client(
         [attestor][google.cloud.binaryauthorization.v1.Attestor] does
         not exist.
 
+        .. code-block:: python
 
-
-        .. code-block::
-
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1
 
             def sample_update_attestor():
@@ -967,27 +1056,37 @@ class BinauthzManagementServiceV1Client(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     def list_attestors(
         self,
-        request: Union[service.ListAttestorsRequest, dict] = None,
+        request: Optional[Union[service.ListAttestorsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListAttestorsPager:
         r"""Lists [attestors][google.cloud.binaryauthorization.v1.Attestor].
         Returns INVALID_ARGUMENT if the project does not exist.
 
+        .. code-block:: python
 
-
-        .. code-block::
-
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1
 
             def sample_list_attestors():
@@ -1066,12 +1165,20 @@ class BinauthzManagementServiceV1Client(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListAttestorsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1079,11 +1186,11 @@ class BinauthzManagementServiceV1Client(
 
     def delete_attestor(
         self,
-        request: Union[service.DeleteAttestorRequest, dict] = None,
+        request: Optional[Union[service.DeleteAttestorRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes an
@@ -1092,10 +1199,15 @@ class BinauthzManagementServiceV1Client(
         [attestor][google.cloud.binaryauthorization.v1.Attestor] does
         not exist.
 
+        .. code-block:: python
 
-
-        .. code-block::
-
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import binaryauthorization_v1
 
             def sample_delete_attestor():
@@ -1161,10 +1273,13 @@ class BinauthzManagementServiceV1Client(
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
-    def __enter__(self):
+    def __enter__(self) -> "BinauthzManagementServiceV1Client":
         return self
 
     def __exit__(self, type, value, traceback):
@@ -1178,14 +1293,9 @@ class BinauthzManagementServiceV1Client(
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-binary-authorization",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("BinauthzManagementServiceV1Client",)
